import { Divider, Menu } from 'antd';
import React from 'react';

interface SiderMenuProps {
  collapsed: boolean;
  selectedKey: string;
  hangleMenuClick: (e: any) => void;
}

export default function SiderMenu({
  collapsed,
  selectedKey,
  hangleMenuClick,
}: SiderMenuProps) {
  const menuItems = [
    {
      key: 'toggle',
      icon: (
        <img
          src={
            !collapsed
              ? './icons/sider/menu_open.svg'
              : './icons/sider/menu.svg'
          }
          alt="toggle"
        />
      ),
      label: 'VORKOUT',
      style: { fontSize: '20px' },
    },
    {
      key: '/process-diagram',
      icon: (
        <img src="./icons/sider/process-diagram.svg" alt="process diagram" />
      ),
      label: 'Схемы процессов',
    },
    {
      key: '/running-processes',
      icon: (
        <img
          src="./icons/sider/running-processes.svg"
          alt="running processes"
        />
      ),
      label: 'Запущенные процессы',
    },
    !collapsed
      ? {
          key: 'divider',
          label: <Divider />,
          style: {
            marginBottom: '-16px',
            marginTop: '-4px',
            cursor: 'default',
          },
          disabled: true,
        }
      : null,
    {
      key: 'sub1',
      icon: <img src="./icons/sider/settings.svg" alt="settings" />,
      label: 'Настройки',
      className: 'no-expand-icon',
      children: [
        {
          key: '/accounts',
          label: 'Учетные записи',
          style: { fontSize: '12px', paddingLeft: '52px' },
        },
        {
          key: '/events-list',
          label: 'Справочник событий',
          style: { fontSize: '12px', paddingLeft: '52px' },
        },
        {
          key: '/configuration',
          label: 'Конфигурация',
          style: { fontSize: '12px', paddingLeft: '52px' },
        },
      ],
    },
  ];

  return (
    <Menu
      theme="light"
      selectedKeys={[selectedKey]}
      mode="inline"
      onClick={hangleMenuClick}
      defaultOpenKeys={['sub1']}
      items={menuItems}
    />
  );
}
